@@ -247,7 +247,7 @@ typedef struct {
    void         *video_planarmem;		/* opaque memory management information structure */
    CARD32       video_planarbuf; 		/* offset in video memory of planar YV12 buffer */
    
-#ifdef XF86DRI
+#ifdef SAVAGEDRI
    Bool         tried_agp;			/* TRUE if AGP allocation has been tried */
    CARD32	agpBase;			/* Physical address of aperture base */
    CARD32	agpBufferOffset;		/* Offset of buffer in AGP memory, or 0 if unavailable */
@@ -338,7 +338,7 @@ SavageClipVWindow(ScrnInfoPtr pScrn)
 
 void SavageInitVideo(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     XF86VideoAdaptorPtr *adaptors, *newAdaptors = NULL;
     XF86VideoAdaptorPtr newAdaptor = NULL;
     SavagePtr psav = SAVPTR(pScrn);
@@ -384,7 +384,7 @@ void SavageInitVideo(ScreenPtr pScreen)
             adaptors = &newAdaptor;
         } else {
             newAdaptors =  /* need to free this someplace */
-        	xalloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr*));
+        	malloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr*));
             if(newAdaptors) {
         	memcpy(newAdaptors, adaptors, num_adaptors * 
         				sizeof(XF86VideoAdaptorPtr));
@@ -399,7 +399,7 @@ void SavageInitVideo(ScreenPtr pScreen)
         xf86XVScreenInit(pScreen, adaptors, num_adaptors);
 
     if(newAdaptors)
-	xfree(newAdaptors);
+	free(newAdaptors);
 
     if( newAdaptor )
     {
@@ -877,14 +877,14 @@ void SavageResetVideo(ScrnInfoPtr pScrn)
 static XF86VideoAdaptorPtr 
 SavageSetupImageVideo(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     SavagePtr psav = SAVPTR(pScrn);
     XF86VideoAdaptorPtr adapt;
     SavagePortPrivPtr pPriv;
 
     xf86ErrorFVerb(XVTRACE,"SavageSetupImageVideo\n");
 
-    if(!(adapt = xcalloc(1, sizeof(XF86VideoAdaptorRec) +
+    if(!(adapt = calloc(1, sizeof(XF86VideoAdaptorRec) +
 			    sizeof(SavagePortPrivRec) +
 			    sizeof(DevUnion))))
 	return NULL;
@@ -1037,8 +1037,9 @@ static void
 SavageStopVideo(ScrnInfoPtr pScrn, pointer data, Bool shutdown)
 {
     SavagePortPrivPtr pPriv = (SavagePortPrivPtr)data;
+#ifdef SAVAGEDRI
     SavagePtr psav = SAVPTR(pScrn);
-    ScreenPtr pScreen = screenInfo.screens[pScrn->scrnIndex];
+#endif
 
     xf86ErrorFVerb(XVTRACE,"SavageStopVideo\n");
 
@@ -1048,7 +1049,7 @@ SavageStopVideo(ScrnInfoPtr pScrn, pointer data, Bool shutdown)
       /*SavageClipVWindow(pScrn);*/
  	SavageStreamsOff( pScrn );
 
-#ifdef XF86DRI
+#ifdef SAVAGEDRI
 	if (pPriv->agpBufferMap != NULL) {
 	    SAVAGEDRIServerPrivatePtr pSAVAGEDRIServer = psav->DRIServerInfo;
 
@@ -1214,7 +1215,6 @@ SavageCopyPlanarDataBCI(
     unsigned long offsetV = offsetY +  srcPitch * h;
     unsigned long offsetU = offsetV +  srcPitch2 * (h>>1);
     unsigned long dstOffset  = (unsigned long)dst - (unsigned long)psav->FBBase;
-    int i;
     unsigned char memType;
     
     BCI_GET_PTR;
@@ -1326,7 +1326,7 @@ SavageCopyPlanarData(
 static void
 SavageVideoSave(ScreenPtr pScreen, ExaOffscreenArea *area)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     SavagePtr psav = SAVPTR(pScrn);
     SavagePortPrivPtr pPriv = psav->adaptor->pPortPrivates[0].ptr;
 
@@ -1342,7 +1342,7 @@ SavageAllocateMemory(
     void **mem_struct,
     int size
 ){
-    ScreenPtr pScreen = screenInfo.screens[pScrn->scrnIndex];
+    ScreenPtr pScreen = xf86ScrnToScreen(pScrn);
     SavagePtr psav = SAVPTR(pScrn);
     int offset = 0;
 
@@ -1505,14 +1505,17 @@ SavageDisplayVideoOld(
       }
 
     if (S3_MOBILE_TWISTER_SERIES(psav->Chipset)
-        && psav->FPExpansion) {
-        drw_w = (((float)(drw_w * psav->XExp1)/(float)psav->XExp2)+1);
-        drw_h = (float)(drw_h * psav->YExp1)/(float)psav->YExp2+1;
-        dstBox->x1 = (float)(dstBox->x1 * psav->XExp1)/(float)psav->XExp2;
-        dstBox->y1 = (float)(dstBox->y1 * psav->YExp1)/(float)psav->YExp2;
-
-        dstBox->x1 += psav->displayXoffset;
-        dstBox->y1 += psav->displayYoffset;
+	&& psav->FPExpansion) {
+	drw_w = (drw_w * psav->XExp1) / psav->XExp2 + 1;
+	drw_h = (drw_h * psav->YExp1) / psav->YExp2 + 1;
+	dstBox->x1 = (dstBox->x1 * psav->XExp1) / psav->XExp2;
+	dstBox->y1 = (dstBox->y1 * psav->YExp1) / psav->YExp2;
+	dstBox->x2 = (dstBox->x2 * psav->XExp1) / psav->XExp2;
+	dstBox->y2 = (dstBox->y2 * psav->YExp1) / psav->YExp2;
+	dstBox->x1 += psav->displayXoffset;
+	dstBox->y1 += psav->displayYoffset;
+	dstBox->x2 += psav->displayXoffset;
+	dstBox->y2 += psav->displayYoffset;
     }
 
     /*
@@ -1666,12 +1669,16 @@ SavageDisplayVideoNew(
 	    !psav->CrtOnly &&
 	    !psav->TvOn) 
     {
-	drw_w = (drw_w * psav->XExp1)/psav->XExp2 + 1;
-	drw_h = (drw_h * psav->YExp1)/psav->YExp2 + 1;
-	dstBox->x1 = (dstBox->x1 * psav->XExp1)/psav->XExp2;
-	dstBox->y1 = (dstBox->y1 * psav->YExp1)/psav->YExp2;
+	drw_w = (drw_w * psav->XExp1) / psav->XExp2 + 1;
+	drw_h = (drw_h * psav->YExp1) / psav->YExp2 + 1;
+	dstBox->x1 = (dstBox->x1 * psav->XExp1) / psav->XExp2;
+	dstBox->y1 = (dstBox->y1 * psav->YExp1) / psav->YExp2;
+	dstBox->x2 = (dstBox->x2 * psav->XExp1) / psav->XExp2;
+	dstBox->y2 = (dstBox->y2 * psav->YExp1) / psav->YExp2;
 	dstBox->x1 += psav->displayXoffset;
 	dstBox->y1 += psav->displayYoffset;
+	dstBox->x2 += psav->displayXoffset;
+	dstBox->y2 += psav->displayYoffset;
     }
 
 	if (psav->IsSecondary) {
@@ -1712,28 +1719,28 @@ SavageDisplayVideoNew(
         OUTREG(SEC_STREAM2_STRIDE_LPB, pitch & 0xfff );
         OUTREG(SEC_STREAM2_WINDOW_START, ((dstBox->x1+1) << 16) | (dstBox->y1+1) );
         OUTREG(SEC_STREAM2_WINDOW_SZ, ((dstBox->x2-dstBox->x1) << 16) 
-	   | (dstBox->x2-dstBox->x1) );
+	   | (dstBox->y2 - dstBox->y1) );
     } else if (psav->IsPrimary) {
         OUTREG(SEC_STREAM_FBUF_ADDR0, (offset + (x1>>15)) 
 	   & (0x7ffffff & ~BASE_PAD));
         OUTREG(SEC_STREAM_STRIDE, pitch & 0xfff );
         OUTREG(SEC_STREAM_WINDOW_START, ((dstBox->x1+1) << 16) | (dstBox->y1+1) );
         OUTREG(SEC_STREAM_WINDOW_SZ, ((dstBox->x2-dstBox->x1) << 16) 
-	   | (dstBox->x2-dstBox->x1) );
+	   | (dstBox->y2 - dstBox->y1) );
     } else {
         OUTREG(SEC_STREAM_FBUF_ADDR0, (offset + (x1>>15)) 
 	   & (0x7ffffff & ~BASE_PAD));
         OUTREG(SEC_STREAM_STRIDE, pitch & 0xfff );
         OUTREG(SEC_STREAM_WINDOW_START, ((dstBox->x1+1) << 16) | (dstBox->y1+1) );
         OUTREG(SEC_STREAM_WINDOW_SZ, ((dstBox->x2-dstBox->x1) << 16) 
-	   | (dstBox->x2-dstBox->x1) );
+	   | (dstBox->y2 - dstBox->y1) );
 #if 0
         OUTREG(SEC_STREAM2_FBUF_ADDR0, (offset + (x1>>15)) 
 	   & (0x7ffffff & ~BASE_PAD));
         OUTREG(SEC_STREAM2_STRIDE_LPB, pitch & 0xfff );
         OUTREG(SEC_STREAM2_WINDOW_START, ((dstBox->x1+1) << 16) | (dstBox->y1+1) );
         OUTREG(SEC_STREAM2_WINDOW_SZ, ((dstBox->x2-dstBox->x1) << 16) 
-	   | (dstBox->x2-dstBox->x1) );
+	   | (dstBox->y2 - dstBox->y1) );
 #endif
     }
 
@@ -1772,15 +1779,24 @@ SavageDisplayVideo2000(
     short drw_w, short drw_h
 ){
     SavagePtr psav = SAVPTR(pScrn);
+#if 0
     vgaHWPtr hwp = VGAHWPTR(pScrn);
+#endif
     /*DisplayModePtr mode = pScrn->currentMode;*/
     SavagePortPrivPtr pPriv = psav->adaptor->pPortPrivates[0].ptr;
+#if 0
     int vgaCRIndex, vgaCRReg, vgaIOBase;
-    CARD32 addr0, addr1, addr2;
+#endif
+    CARD32 addr0;
+#if 0
+    CARD32 addr1, addr2;
+#endif
 
+#if 0
     vgaIOBase = hwp->IOBase;
     vgaCRIndex = vgaIOBase + 4;
     vgaCRReg = vgaIOBase + 5;
+#endif
 
 
     if( psav->videoFourCC != id )
@@ -1828,8 +1844,10 @@ SavageDisplayVideo2000(
      */
 
     addr0 = offset + (x1>>15); /* Y in YCbCr420 */
+#if 0
     addr1 = addr0 + (width * height); /* Cb in in YCbCr420 */
     addr2 = addr1 + ((width * height) / 4); /* Cr in in YCbCr420 */
+#endif
     OUTREG(SEC_STREAM_FBUF_ADDR0, (addr0) & (0x3fffff & ~BASE_PAD));
 #if 0
     OUTREG(SEC_STREAM_FBUF_ADDR1, (addr1) & (0x3fffff & ~BASE_PAD));
@@ -1895,10 +1913,12 @@ SavagePutImage(
 ){
     SavagePortPrivPtr pPriv = (SavagePortPrivPtr)data;
     SavagePtr psav = SAVPTR(pScrn);
+#ifdef SAVAGEDRI
     ScreenPtr pScreen = pScrn->pScreen;
+#endif
     INT32 x1, x2, y1, y2;
     unsigned char *dst_start;
-    int pitch, new_size, offset, offsetV=0, offsetU=0;
+    int new_size, offset, offsetV=0, offsetU=0;
     int srcPitch, srcPitch2=0, dstPitch;
     int planarFrameSize;
     int top, left, npixels, nlines;
@@ -1934,8 +1954,6 @@ SavagePutImage(
     dstBox.y1 -= pScrn->frameY0;
     dstBox.y2 -= pScrn->frameY0;
 
-    pitch = pScrn->bitsPerPixel * pScrn->displayWidth >> 3;
-
     /* All formats directly displayable by Savage are packed and 2 bytes per pixel */
     dstPitch = ((width << 1) + 15) & ~15;
     new_size = dstPitch * height;
@@ -1973,9 +1991,8 @@ SavagePutImage(
 
     /* Check whether AGP buffers can be allocated. If not, fall back to ordinary
        upload to framebuffer (slower) */
-#ifdef XF86DRI
+#ifdef SAVAGEDRI
     if (!pPriv->tried_agp && !psav->IsPCI && psav->drmFD > 0 && psav->DRIServerInfo != NULL) {
-        int ret;
 	SAVAGEDRIServerPrivatePtr pSAVAGEDRIServer = psav->DRIServerInfo;
         
 	pPriv->tried_agp = TRUE;
@@ -2003,14 +2020,14 @@ SavagePutImage(
 	    /* This situation is expected if AGPforXv is disabled, otherwise report. */
 	    if (pSAVAGEDRIServer->agpXVideo.size > 0) {
 		xf86DrvMsg( pScreen->myNum, X_ERROR,
-		    "[agp] XVideo: not enough space in buffer (got %ld bytes, required %ld bytes).\n", 
-	    	    pSAVAGEDRIServer->agpXVideo.size, max(new_size, planarFrameSize));
+		    "[agp] XVideo: not enough space in buffer (got %ld bytes, required %d bytes).\n", 
+	    	    (long int)pSAVAGEDRIServer->agpXVideo.size, max(new_size, planarFrameSize));
 	    }
 	    pPriv->agpBufferMap = NULL;
 	    pPriv->agpBufferOffset = 0;
 	}
     }
-#endif /* XF86DRI */
+#endif /* SAVAGEDRI */
 
 
     /* Buffer for final packed frame */
@@ -2056,7 +2073,7 @@ SavagePutImage(
 	offsetV += tmp;
 	nlines = ((((y2 + 0xffff) >> 16) + 1) & ~1) - top;
         if (S3_SAVAGE4_SERIES(psav->Chipset) && psav->BCIforXv && (npixels & 0xF) == 0 && pPriv->video_planarbuf != 0) {
-#ifdef XF86DRI
+#ifdef SAVAGEDRI
             if (pPriv->agpBufferMap != NULL) {
 		/* Using copy to AGP memory */
 		SavageCopyPlanarDataBCI(
@@ -2069,7 +2086,7 @@ SavagePutImage(
 		    pPriv->agpBase + pPriv->agpBufferOffset,
 		    srcPitch, srcPitch2, dstPitch, nlines, npixels, TRUE);
             } else
-#endif /* XF86DRI */
+#endif /* SAVAGEDRI */
             {
 		/* Using ordinary copy to framebuffer */
 		SavageCopyPlanarDataBCI(
@@ -2188,7 +2205,7 @@ SavageAllocateSurface(
     XF86SurfacePtr surface
 ){
     int offset, size;
-    int pitch, fbpitch, numlines;
+    int pitch;
     void *surface_memory = NULL;
     OffscreenPrivPtr pPriv;
 
@@ -2197,8 +2214,6 @@ SavageAllocateSurface(
 
     w = (w + 1) & ~1;
     pitch = ((w << 1) + 15) & ~15;
-    fbpitch = pScrn->bitsPerPixel * pScrn->displayWidth >> 3;
-    numlines = ((pitch * h) + fbpitch - 1) / fbpitch;
     size = pitch * h;
 
     offset = SavageAllocateMemory(pScrn, &surface_memory, size);
@@ -2208,18 +2223,18 @@ SavageAllocateSurface(
     surface->width = w;
     surface->height = h;
 
-    if(!(surface->pitches = xalloc(sizeof(int)))) {
+    if(!(surface->pitches = malloc(sizeof(int)))) {
 	SavageFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
-    if(!(surface->offsets = xalloc(sizeof(int)))) {
-	xfree(surface->pitches);
+    if(!(surface->offsets = malloc(sizeof(int)))) {
+	free(surface->pitches);
 	SavageFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
-    if(!(pPriv = xalloc(sizeof(OffscreenPrivRec)))) {
-	xfree(surface->pitches);
-	xfree(surface->offsets);
+    if(!(pPriv = malloc(sizeof(OffscreenPrivRec)))) {
+	free(surface->pitches);
+	free(surface->offsets);
 	SavageFreeMemory(pScrn, surface_memory);
 	return BadAlloc;
     }
@@ -2264,9 +2279,9 @@ SavageFreeSurface(
     if(pPriv->isOn)
 	SavageStopSurface(surface);
     SavageFreeMemory(pScrn, pPriv->surface_memory);
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
 
     return Success;
 }
@@ -2335,7 +2350,7 @@ SavageDisplaySurface(
 	     surface->width, surface->height, surface->pitches[0],
 	     x1, y1, x2, y2, &dstBox, src_w, src_h, drw_w, drw_h);
 
-    xf86XVFillKeyHelper(pScrn->pScreen, portPriv->colorKey, clipBoxes);
+    xf86XVFillKeyHelper(pScreen, portPriv->colorKey, clipBoxes);
 
     pPriv->isOn = TRUE;
 #if 0
@@ -2355,11 +2370,11 @@ static void
 SavageInitOffscreenImages(ScreenPtr pScreen)
 {
     XF86OffscreenImagePtr offscreenImages;
-    SavagePtr psav = SAVPTR(xf86Screens[pScreen->myNum]);
+    SavagePtr psav = SAVPTR(xf86ScreenToScrn(pScreen));
 
     /* need to free this someplace */
     if (!psav->offscreenImages) {
-	if(!(offscreenImages = xalloc(sizeof(XF86OffscreenImageRec))))
+	if(!(offscreenImages = malloc(sizeof(XF86OffscreenImageRec))))
 	    return;
 	psav->offscreenImages = offscreenImages;
     } else {
